==> redpesk-cli_3.15.0.orig.tar.gz: redpesk-cli-3.15.0/cmd/builds_constants.go <==
/*
Copyright © 2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// Build command
	genericBuildCmd           = "build <%s>"
	genericBuildAlias         = "bld"
	genericBuildCmdShortUsage = "Start building an %s on the redpesk factory"
	genericBuildCmdLongUsage  = `Start building an %s on the redpesk factory
An object "%s" needs to have been created in the backend with all the rights parameters (cf. 'rp-cli %s add --help').`
	genericBuildCmdAnsLine0 = "-- %s build requested by user --"
	genericBuildCmdAnsLine1 = "Building the \"%s\" %s...\n"
	genericBuildCmdAnsLine2 = "------ Build subtask event received -----"
	genericBuildCmdAnsLine3 = "---------- Build event received ---------"
	genericBuildCmdAnsLine4 = "-----------------------------------------"
	genericBuildCmdAnsLine5 = "--------- %s build done --------"
	genericBuildCmdAnsLine6 = "-------- %s build failed -------"
	genericBuildCmdAnsLine7 = "-- %s build #%s canceled --\n"
	genericBuildCmdAnsLine8 = "------- %s build canceled ------"

	genericBuildCmdVerboseLine0          = "Build ID:\t"
	genericBuildCmdVerboseLine13         = "Build type:\t"
	appsBuildCmdVerboseLine1             = "Application ID:\t"
	appsBuildCmdVerboseLine8             = "Application slug:\t"
	imgsBuildCmdVerboseLine1             = "Image ID: \t"
	imgsBuildCmdVerboseLine2             = "Image slug: \t"
	genericBuildCmdVerboseLine7          = "Distribution:\t"
	genericBuildCmdVerboseLine2          = "Status:\t"
	genericBuildCmdVerboseLine9          = "Comment:\t"
	genericBuildCmdVerboseLine12         = "SRPM build ID:\t"
	genericBuildCmdVerboseLine3          = "Subtask:\t"
	genericBuildCmdVerboseLine4          = "Subtask state:\t"
	genericBuildCmdVerboseLine5          = "Subtask method:\t"
	genericBuildCmdVerboseLine6          = "Subtask method description:\t"
	genericBuildCmdVerboseLine10         = "SRPM file #%d:\t"
	genericBuildCmdVerboseLine11         = "RPM file #%d:\t"
	genericBuildCmdVerboseLogFileTag     = "[Log files]"
	genericBuildCmdVerboseSRPMFileTag    = "[SRPM files]"
	genericBuildCmdVerboseRPMFileTag     = "[RPM files]"
	genericBuildCmdVerboseFilesTag       = "[Files]"
	genericBuildCmdVerboseErrorFaultCode = "Error code:\t"
	genericBuildCmdVerboseErrorFaultMsg  = "Error message:\t"

	genericBuildLiveCmdLinePart0      = "%s Build: %-4v ["
	genericBuildLiveCmdLinePart1      = "] -- %-8v"
	genericBuildLiveCmdLineComplement = " -- Subtasks: "

	genericBuildLiveLabelStatusChange = "[STATUS CHANGE]"
	genericBuildLiveLabelSuccess      = "[RESULT][SUCCESS ]"
	genericBuildLiveLabelFailed       = "[RESULT][FAILED  ]"
	genericBuildLiveLabelCanceled     = "[RESULT][CANCELED]"

	genericBuildCmdLine0 = "Build ID:\t"
	genericBuildCmdLine1 = "Status:\t"
	genericBuildCmdLine2 = "Subtask %s status:\t%s\n"

	genericBuildListHeader = "ID\t Status"

	appsBuildCmdDistroFlag      = "distribution"
	appsBuildCmdDistroFlagAlias = "d"
	appsBuildCmdDistroFlagUsage = "[Optional] Specify the distribution targeted by the build (can be set several times for several distributions)"

	appsBuildCmdCommentFlag      = "comment"
	appsBuildCmdCommentFlagAlias = "c"
	appsBuildCmdCommentFlagUsage = "[Optional] Additional information to save with the build data"

	appsBuildCmdSrpmFlag      = "srpm"
	appsBuildCmdSrpmFlagAlias = "s"
	appsBuildCmdSrpmFlagUsage = "[Optional] Restart a srpm build only"

	appsBuildCmdCheckDepsFlag      = "check-deps"
	appsBuildCmdCheckDepsFlagAlias = "e"
	appsBuildCmdCheckDepsFlagUsage = "[Optional] Restart the 'check dependencies' subtask only"

	// Builds command group
	genericBuildsCmd           = "builds"
	genericBuildsCmdShortUsage = "Group of subcommands relative to \"builds\" of an %s"

	// Builds list command
	genericSubBuildsListCmd           = "list <%s>"
	genericSubBuildsListAlias         = "ls"
	genericSubBuildsListCmdShortUsage = "List all the builds of an %s"

	appsSubBuildsListCmdSRpmFlag      = "srpm"
	appsSubBuildsListCmdSRpmFlagAlias = "s"
	appsSubBuildsListCmdSRpmFlagUsage = "[Optional] Display only srpm builds"

	// Get command
	genericBuildsGetCmd           = "get {<%s>|<build-ID>}"
	genericBuildsGetCmdShortUsage = "Get the properties of a build"
	genericBuildsGetCmdLongUsage  = `Get the properties of a build.
Either the %s ID or the build ID can be specified. In the first case the latest build is retrieved.
If your %s ID looks like a build ID (i.e. it is uniquely an integer), please use the '--force-%s' flag.`

	// Builds logs command
	genericBuildLogsCmd           = "logs {<%s>|<build-ID>}"
	genericBuildLogsCmdShortUsage = "Download the %s build logs"
	genericBuildLogsCmdLongUsage  = `Download the %s build logs in a directory.
Either the %s ID or the build ID can be specified. In the first case the latest build is retrieved.
If your %s ID looks like a build ID (i.e. it is uniquely an integer), please use the '--force-%s' flag.`
	genericBuildLogsCmdAnsLine0 = "------ Retrieving build logs files -----"
	genericBuildLogsCmdAnsLine1 = "Downloading logs for subtask \"%s\"...\n"
	genericBuildLogsCmdAnsLine2 = "No logs available for subtask \"%s\"\n"
	genericBuildLogsCmdAnsLine3 = "A problem appeared while downloading \"%s\": %v\n"
	genericBuildLogsCmdAnsLine4 = "The build logs for build \"%d\" are available in: %s\n"

	genericBuildLogsDirFlag        = "directory"
	genericBuildLogsDirFlagAlias   = "d"
	genericBuildLogsDirFlagUsage   = "Path to the download target directory"
	genericBuildLogsDirFlagDefault = "./"

	genericBuildZipFlag      = "zip"
	genericBuildZipFlagAlias = "z"
	genericBuildZipFlagUsage = "Request to archive the logs into a zip file"

	// Builds cancel command
	genericBuildsCancelCmd           = "cancel {<%s>|<build-ID>}"
	genericBuildsCancelCmdShortUsage = "Cancel a running build"
	genericBuildsCancelCmdLongUsage  = `Cancel a running build.
Either the %s ID or the build ID can be specified. In the first case the latest build is cancelled.
If your %s ID looks like a build ID (i.e. it is uniquely an integer), please use the '--force-%s' flag.`
	genericBuildsCancelCmdAnsLine0 = "-- Build cancellation requested by user --"
	genericBuildsCancelCmdAnsLine1 = "Cancelling build #%d...\t"

	// Error messages
	genericNoBuildFoundErr = "no build found for the given object ID '%s'"
)

==> redpesk-cli_3.18.3.orig.tar.gz: redpesk-cli-3.18.3/cmd/builds_constants.go <==
/*
Copyright © 2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// Build command
	genericBuildCmd           = "build <%s>"
	genericBuildAlias         = "bld"
	genericBuildCmdShortUsage = "Start building an %s on the redpesk factory"
	genericBuildCmdLongUsage  = `Start building an %s on the redpesk factory
An object "%s" needs to have been created in the backend with all the rights parameters (cf. 'rp-cli %s add --help').`
	genericBuildCmdAnsLine0 = "-- %s build requested by user --"
	genericBuildCmdAnsLine1 = "Building the \"%s\" %s...\n"
	genericBuildCmdAnsLine2 = "------ Build subtask event received -----"
	genericBuildCmdAnsLine3 = "---------- Build event received ---------"
	genericBuildCmdAnsLine4 = "-----------------------------------------"
	genericBuildCmdAnsLine5 = "--------- %s build done --------"
	genericBuildCmdAnsLine6 = "-------- %s build failed -------"
	genericBuildCmdAnsLine7 = "-- %s build #%s canceled --\n"
	genericBuildCmdAnsLine8 = "------- %s build canceled ------"

	genericBuildCmdVerboseLine0          = "Build ID:\t"
	genericBuildCmdVerboseLine13         = "Build type:\t"
	appsBuildCmdVerboseLine1             = "Application ID:\t"
	appsBuildCmdVerboseLine8             = "Application slug:\t"
	imgsBuildCmdVerboseLine1             = "Image ID: \t"
	imgsBuildCmdVerboseLine2             = "Image slug: \t"
	genericBuildCmdVerboseLine14         = "Built by: \t"
	genericBuildCmdVerboseLine7          = "Distribution:\t"
	genericBuildCmdVerboseLine2          = "Status:\t"
	genericBuildCmdVerboseLine9          = "Comment:\t"
	genericBuildCmdVerboseLine12         = "SRPM build ID:\t"
	genericBuildCmdVerboseLine3          = "Subtask:\t"
	genericBuildCmdVerboseLine4          = "Subtask state:\t"
	genericBuildCmdVerboseLine5          = "Subtask method:\t"
	genericBuildCmdVerboseLine6          = "Subtask method description:\t"
	genericBuildCmdVerboseLine10         = "SRPM file #%d:\t"
	genericBuildCmdVerboseLine11         = "RPM file #%d:\t"
	genericBuildCmdVerboseLogFileTag     = "[Log files]"
	genericBuildCmdVerboseSRPMFileTag    = "[SRPM files]"
	genericBuildCmdVerboseRPMFileTag     = "[RPM files]"
	genericBuildCmdVerboseFilesTag       = "[Files]"
	genericBuildCmdVerboseErrorFaultCode = "Error code:\t"
	genericBuildCmdVerboseErrorFaultMsg  = "Error message:\t"

	genericBuildLiveCmdLinePart0      = "%s Build: %-4v ["
	genericBuildLiveCmdLinePart1      = "] -- %-8v"
	genericBuildLiveCmdLineComplement = " -- Subtasks: "

	genericBuildLiveLabelStatusChange = "[STATUS CHANGE]"
	genericBuildLiveLabelSuccess      = "[RESULT][SUCCESS ]"
	genericBuildLiveLabelFailed       = "[RESULT][FAILED  ]"
	genericBuildLiveLabelCanceled     = "[RESULT][CANCELED]"

	genericBuildCmdLine0 = "Build ID:\t"
	genericBuildCmdLine1 = "Status:\t"
	genericBuildCmdLine2 = "Subtask %s status:\t%s\n"

	genericBuildListHeader = "ID\t Status"

	appsBuildCmdDistroFlag      = "distribution"
	appsBuildCmdDistroFlagAlias = "d"
	appsBuildCmdDistroFlagUsage = "[Optional] Specify the distribution targeted by the build (can be set several times for several distributions)"

	genericBuildCmdCommentFlag      = "comment"
	genericBuildCmdCommentFlagAlias = "c"
	genericBuildCmdCommentFlagUsage = "[Optional] Additional information to save with the build data"

	appsBuildCmdSrpmFlag      = "srpm"
	appsBuildCmdSrpmFlagAlias = "s"
	appsBuildCmdSrpmFlagUsage = "[Optional] Restart a srpm build only"

	appsBuildCmdCheckDepsFlag      = "check-deps"
	appsBuildCmdCheckDepsFlagAlias = "e"
	appsBuildCmdCheckDepsFlagUsage = "[Optional] Restart the 'check dependencies' subtask only"

	prjsBuildCmdAppFlag      = "apps"
	prjsBuildCmdAppFlagAlias = "a"
	prjsBuildCmdAppFlagUsage = "[Optional] Specify applications targeted by the build (can be set several times for several applications)"

	prjsBuildCmdImgFlag      = "images"
	prjsBuildCmdImgFlagAlias = "i"
	prjsBuildCmdImgFlagUsage = "[Optional] Specify images targeted by the build (can be set several times for several images)"

	// Builds command group
	genericBuildsCmd           = "builds"
	genericBuildsCmdShortUsage = "Group of subcommands relative to \"builds\" of an %s"

	// Builds list command
	genericSubBuildsListCmd           = "list <%s>"
	genericSubBuildsListAlias         = "ls"
	genericSubBuildsListCmdShortUsage = "List all the builds of an %s"

	appsSubBuildsListCmdSRpmFlag      = "srpm"
	appsSubBuildsListCmdSRpmFlagAlias = "s"
	appsSubBuildsListCmdSRpmFlagUsage = "[Optional] Display only srpm builds"

	// Get command
	genericBuildsGetCmd           = "get {<%s>|<build-ID>}"
	genericBuildsGetCmdShortUsage = "Get the properties of a build"
	genericBuildsGetCmdLongUsage  = `Get the properties of a build.
Either the %s ID or the build ID can be specified. In the first case the latest build is retrieved.
If your %s ID looks like a build ID (i.e. it is uniquely an integer), please use the '--force-%s' flag.`

	// Builds logs command
	genericBuildLogsCmd           = "logs {<%s>|<build-ID>}"
	genericBuildLogsCmdShortUsage = "Download the %s build logs"
	genericBuildLogsCmdLongUsage  = `Download the %s build logs in a directory.
Either the %s ID or the build ID can be specified. In the first case the latest build is retrieved.
If your %s ID looks like a build ID (i.e. it is uniquely an integer), please use the '--force-%s' flag.`
	genericBuildLogsCmdAnsLine0 = "------ Retrieving build logs files -----"
	genericBuildLogsCmdAnsLine1 = "Downloading logs for subtask \"%s\"...\n"
	genericBuildLogsCmdAnsLine2 = "No logs available for subtask \"%s\"\n"
	genericBuildLogsCmdAnsLine3 = "A problem appeared while downloading \"%s\": %v\n"
	genericBuildLogsCmdAnsLine4 = "The build logs for build \"%d\" are available in: %s\n"

	genericBuildLogsDirFlag        = "directory"
	genericBuildLogsDirFlagAlias   = "d"
	genericBuildLogsDirFlagUsage   = "Path to the download target directory"
	genericBuildLogsDirFlagDefault = "./"

	genericBuildZipFlag      = "zip"
	genericBuildZipFlagAlias = "z"
	genericBuildZipFlagUsage = "Request to archive the logs into a zip file"

	// Builds cancel command
	genericBuildsCancelCmd           = "cancel {<%s>|<build-ID>}"
	genericBuildsCancelCmdShortUsage = "Cancel a running build"
	genericBuildsCancelCmdLongUsage  = `Cancel a running build.
Either the %s ID or the build ID can be specified. In the first case the latest build is cancelled.
If your %s ID looks like a build ID (i.e. it is uniquely an integer), please use the '--force-%s' flag.`
	genericBuildsCancelCmdAnsLine0 = "-- Build cancellation requested by user --"
	genericBuildsCancelCmdAnsLine1 = "Cancelling build #%d...\t"

	// Error messages
	genericNoBuildFoundErr = "no build found for the given object ID '%s'"
)
